@@ -1,4 +1,6 @@
-from pandas import DataFrame
+from pandas import DataFrame as PandasDF
+from pyspark.sql import DataFrame as SparkDF
+from pyspark.sql import functions as f
 
 from ...text import remove_non_alphanumeric
 from ...text import convert_camel_to_snake
@@ -39,20 +41,26 @@ def remove_non_alphanumeric_lower_and_join(x, camel_to_snake=True, replace_with
 
 def standardize_columns(data, inplace=False, camel_to_snake=True):
 	"""
-	:type data: DataFrame
+	:type data: PandasDF or SparkDF
 	:type inplace: bool
 	:type camel_to_snake: bool
-	:rtype: DataFrame
+	:rtype: PandasDF or SparkDF
 	"""
-	if inplace:
-		new_data = data
-	else:
-		new_data = data.copy()
+	if isinstance(data, PandasDF):
+		if inplace:
+			new_data = data
+		else:
+			new_data = data.copy()
 
-	new_data.columns = list(map(
-		lambda x: remove_non_alphanumeric_lower_and_join(x=x, camel_to_snake=camel_to_snake),
-		list(new_data.columns)
-	))
+		new_data.columns = list(map(
+			lambda x: remove_non_alphanumeric_lower_and_join(x=x, camel_to_snake=camel_to_snake),
+			list(new_data.columns)
+		))
 
-	return new_data
+		return new_data
 
+	elif isinstance(data, SparkDF):
+		return data.select([
+			f.col(col).alias(remove_non_alphanumeric_lower_and_join(x=col, camel_to_snake=camel_to_snake))
+			for col in data.columns
+		])
